@@ -15,7 +15,6 @@ functions to read METRANET files in pure python, no other library required!
     _get_radar_site_info
     _nyquist_vel
     _selex2deg
-    _float_mapping
 
 .. autosummary::
     :toctree: generated/
@@ -36,10 +35,11 @@ import traceback
 
 import numpy as np
 
+from . import metranet_reader
 from .pmfile_structure import MSWEEP_HEADER, MRAY_HEADER, MMOMENT_HEADER, MMOMENT_INFO_STRUCTURE
 from .pmfile_structure import BYTE_SIZES
 from .pmfile_structure import PRAY_HEADER, PMOMENTS
-from .dn_to_float import float_mapping, nyquist_vel
+from .dn_to_float import float_mapping_m, float_mapping_p, nyquist_vel
 from .lzw15 import decompress, readbytes_fh, unpackbyte
 
 # fix for python3
@@ -52,11 +52,6 @@ if sys.version_info[0] == 3:
 ###############################################################################
 
 
-# some values valid for all sites
-NPM_MOM = 11
-NPH_MOM = 12
-NPL_MOM = 9
-
 # For some reasons, the radar name is not encoded in a consistent way in the
 # M binary files, this maps all names in files to a single character
 RENAME_RADARS_M = {'Weissfluhgipfel':'W',
@@ -269,6 +264,7 @@ class PolarParser():
         head = {}
         head['antmode'] = pol_header[0]['antmode']
         head['radarname'] = pol_header[0]['scanid']
+        head['moments'] = moments
         # Rename radar with appropriate dict if needed, otherwise get name from file
         if head['radarname'] in RENAME_RADARS_P.keys():
             head['radarname'] = RENAME_RADARS_P[head['radarname']]
@@ -483,22 +479,34 @@ def read_polar(filename, moments=None, physic_value=True, masked_array=True,
             moments_data[m], dtype=moments_data[m][0].dtype)
 
         if masked_array:
-            if parser.file_type == 'L' and m in ['UZ','UZ_V','Z_V_CLUT','Z_CLUT']:
+            if parser.file_type == 'L' and m in ['UZ','UZ_V','Z_V_CLUT',
+                                                 'Z_CLUT']:
                 mask = np.logical_or(
                     moments_data[m] == 0, moments_data[m] == 1)
             else:
                 mask = moments_data[m] == 0
-
-        # Rename moment if needed
-        if m in MOM_NAME_MAPPING.keys():
-            moments_data[MOM_NAME_MAPPING[m]] = moments_data.pop(m)
-            m = MOM_NAME_MAPPING[m]
+                
+        if parser.file_format == 'M':
+            idx_mom_head = [h['name'] == m
+                                    for h in head['moments']].index(True)
+            if m in MOM_NAME_MAPPING.keys():
+                moments_data[MOM_NAME_MAPPING[m]] = moments_data.pop(m)
+                m = MOM_NAME_MAPPING[m]
 
         if physic_value:
-            moments_data[m] = float_mapping(
-                m, pol_header[0]['datatime'], head['radarname'],
-                nyquist_vel(head['currentsweep'] - 1))[
-                    moments_data[m]].astype(np.float32)
+            if parser.file_format == 'M':
+                moments_data[m] = float_mapping_m(
+                        m, head['moments'][idx_mom_head],
+                        pol_header[0]['datatime'], head['radarname'],
+                        nyquist_vel(head['currentsweep'] - 1))[
+                            moments_data[m]].astype(np.float32)
+            else:
+                moments_data[m] = float_mapping_p(
+                        m, pol_header[0]['datatime'], head['radarname'],
+                        nyquist_vel(head['currentsweep'] - 1))[
+                            moments_data[m]].astype(np.float32) 
+        # Rename moment if needed
+
 
         if masked_array:
             moments_data[m] = np.ma.array(moments_data[m], mask=mask)
@@ -756,9 +764,9 @@ def _get_radar_site_info(verbose=False):
         radar_default['SweepsOrder'] = (
             9, 7, 5, 3, 1, 19, 17, 15, 13, 11, 10, 8, 6, 4, 2, 20, 18, 16, 14,
             12)
-        radar_default['NumMomentsPM'] = NPM_MOM
-        radar_default['NumMomentsPH'] = NPH_MOM
-        radar_default['NumMomentsPL'] = NPL_MOM
+        radar_default['NumMomentsPM'] = metranet_reader.NPM_MOM
+        radar_default['NumMomentsPH'] = metranet_reader.NPH_MOM
+        radar_default['NumMomentsPL'] = metranet_reader.NPL_MOM
 
         radar_def = {}
 
