@@ -34,14 +34,16 @@ from .metranet_c import read_polar as read_polar_c
 from .dn_to_float import nyquist_vel
 # check existence of METRANET library
 try:
-    METRANET_LIB = get_library(momentms=False)
+    METRANET_LIB = get_library(momentms=False, momentpm=True)
     if platform.system() == 'Linux':
         METRANET_LIB = get_library(momentms=True)
     _METRANETLIB_AVAILABLE = True
-except SystemExit:
+except:
+    # bare exception needed to capture error
     _METRANETLIB_AVAILABLE = False
 
 METRANET_FIELD_NAMES = {
+    'SNR': 'signal_to_noise_ratio',
     'WID': 'spectrum_width',
     'VEL': 'velocity',
     'ZH': 'reflectivity',
@@ -58,15 +60,15 @@ METRANET_FIELD_NAMES = {
     'ZVC': 'reflectivity_hh_clut',  # cluttered vertical reflectivity
 }
 
-PM_MOM = ["ZH", "ZV", "ZDR", "RHO", "PHI", "VEL", "WID", "ST1", "ST2", "WBN",
-          "MPH"]
-PH_MOM = ["ZH", "ZV", "ZDR", "RHO", "PHI", "VEL", "WID", "ST1", "ST2", "WBN",
-          "MPH", "CLT"]
-PL_MOM = ["ZH", "ZV", "ZDR", "RHO", "PHI", "VEL", "WID", "ZHC", "ZVC"]
+PM_MOM = ["SNR", "ZH", "ZV", "ZDR", "RHO", "PHI", "VEL", "WID", "ST1", "ST2",
+          "WBN", "MPH"]
+PH_MOM = ["SNR", "ZH", "ZV", "ZDR", "RHO", "PHI", "VEL", "WID", "ST1", "ST2",
+          "WBN", "MPH", "CLT"]
+PL_MOM = ["SNR", "ZH", "ZV", "ZDR", "RHO", "PHI", "VEL", "WID", "ZHC", "ZVC"]
 
-NPM_MOM = 11
-NPH_MOM = 12
-NPL_MOM = 9
+NPM_MOM = 12
+NPH_MOM = 13
+NPL_MOM = 10
 
 
 def read_metranet(filename, field_names=None, rmax=0.,
@@ -291,7 +293,7 @@ def read_metranet_c(filename, field_names=None, rmax=0.,
                     az_data[i] = start_angle + (end_angle-start_angle)/2.
                 else:
                     az_data[i] = start_angle + (end_angle+360.-start_angle)/2.
-                if az_data[i] > 360: # Can happen in spurious cases
+                if az_data[i] > 360:  # Can happen in spurious cases
                     az_data[i] -= 360
             else:
                 valid_rays[i] = 0
@@ -404,7 +406,7 @@ def read_metranet_c(filename, field_names=None, rmax=0.,
         ray_index_data[i] = ret.pol_header[i].sequence
 
     sweep_start = min(time_data)
-    start_time = datetime.datetime.utcfromtimestamp(sweep_start)
+    start_time = datetime.datetime.utcfromtimestamp(int(sweep_start))
     _time['data'] = time_data-sweep_start
     _time['units'] = make_time_unit_str(start_time)
 
@@ -470,7 +472,6 @@ def read_metranet_c(filename, field_names=None, rmax=0.,
 
     # fields
     fields = {}
-
     # ZH field
     field_name = filemetadata.get_field_name('ZH')
     if field_name is not None:
@@ -490,13 +491,14 @@ def read_metranet_c(filename, field_names=None, rmax=0.,
 
     # rest of fields
     if bfile.startswith('PM') or bfile.startswith('MS'):
-        for i in range(1, NPM_MOM):
+        for i in range(0, NPM_MOM):
             field_name = filemetadata.get_field_name(PM_MOM[i])
             if field_name is not None:
                 ret = read_polar_c(
                     filename, PM_MOM[i], physic_value=True, masked_array=True)
                 if ret is None:
-                    warn('Unable to read moment '+PM_MOM[i]+' in file '+filename)
+                    warn(f'Unable to read moment {PM_MOM[i]} in file'
+                         f' {filename}')
                     continue
                 # create field dictionary
                 field_dic = filemetadata(field_name)
@@ -512,13 +514,14 @@ def read_metranet_c(filename, field_names=None, rmax=0.,
                 field_dic['_FillValue'] = get_fillvalue()
                 fields[field_name] = field_dic
     elif bfile.startswith('PH') or bfile.startswith('MH'):
-        for i in range(1, NPH_MOM):
+        for i in range(0, NPH_MOM):
             field_name = filemetadata.get_field_name(PH_MOM[i])
             if field_name is not None:
                 ret = read_polar_c(
                     filename, PH_MOM[i], physic_value=True, masked_array=True)
                 if ret is None:
-                    warn('Unable to read moment '+PH_MOM[i]+' in file '+filename)
+                    warn(f'Unable to read moment {PH_MOM[i]} in file'
+                         f' {filename}')
                     continue
                 # create field dictionary
                 field_dic = filemetadata(field_name)
@@ -533,13 +536,14 @@ def read_metranet_c(filename, field_names=None, rmax=0.,
                 field_dic['_FillValue'] = get_fillvalue()
                 fields[field_name] = field_dic
     else:
-        for i in range(1, NPL_MOM):
+        for i in range(0, NPL_MOM):
             field_name = filemetadata.get_field_name(PL_MOM[i])
             if field_name is not None:
                 ret = read_polar_c(
                     filename, PL_MOM[i], physic_value=True, masked_array=True)
                 if ret is None:
-                    warn('Unable to read moment '+PL_MOM[i]+' in file '+filename)
+                    warn(f'Unable to read moment {PL_MOM[i]} in file'
+                         f' {filename}')
                     continue
 
                 # create field dictionary
@@ -559,7 +563,7 @@ def read_metranet_c(filename, field_names=None, rmax=0.,
         raise ValueError('No valid moments found in '+filename)
 
     # instrument_parameters
-    instrument_parameters = dict()
+    instrument_parameters = {}
     instrument_parameters.update({'frequency': frequency})
     instrument_parameters.update({'radar_beam_width_h': beamwidth_h})
     instrument_parameters.update({'radar_beam_width_v': beamwidth_v})
@@ -695,7 +699,7 @@ def read_metranet_python(filename, field_names=None, rmax=0.,
 
     ant_mode = ret.header['antmode']  # scanning mode code
 
-    no_missing_az = True # will be checked later on
+    no_missing_az = True  # will be checked later on
     if ant_mode == 0:
         scan_type = 'ppi'
         sweep_mode['data'] = np.array(['azimuth_surveillance'])
@@ -709,7 +713,6 @@ def read_metranet_python(filename, field_names=None, rmax=0.,
         start_az = np.deg2rad(start_az)
         end_az = np.deg2rad(end_az)
 
-
         az_data = np.rad2deg(
             circmean(np.column_stack((start_az, end_az)), axis=1))
 
@@ -756,7 +759,6 @@ def read_metranet_python(filename, field_names=None, rmax=0.,
         start_az = np.deg2rad(start_az)
         end_az = np.deg2rad(end_az)
 
-
         az_data = np.rad2deg(
             circmean(np.column_stack((start_az, end_az)), axis=1))
 
@@ -826,7 +828,7 @@ def read_metranet_python(filename, field_names=None, rmax=0.,
     ray_index_data = range(total_record)
 
     sweep_start = min(time_data)
-    start_time = datetime.datetime.utcfromtimestamp(sweep_start)
+    start_time = datetime.datetime.utcfromtimestamp(int(sweep_start))
     _time['data'] = time_data-sweep_start
     _time['units'] = make_time_unit_str(start_time)
 
@@ -941,7 +943,7 @@ def read_metranet_python(filename, field_names=None, rmax=0.,
         raise ValueError('No valid moments found in '+filename)
 
     # instrument_parameters
-    instrument_parameters = dict()
+    instrument_parameters = {}
     instrument_parameters.update({'frequency': frequency})
     instrument_parameters.update({'radar_beam_width_h': beamwidth_h})
     instrument_parameters.update({'radar_beam_width_v': beamwidth_v})
