@@ -20,6 +20,8 @@ Radar retrievals
     kdp_leastsquare_double_window
     calculate_snr_from_reflectivity
     calculate_velocity_texture
+    get_ml_rng_limits
+    get_iso0_val
     compute_ccor
     compute_snr
     compute_l
@@ -36,6 +38,12 @@ Radar retrievals
     map_profile_to_gates
     steiner_conv_strat
     hydroclass_semisupervised
+    data_for_centroids
+    select_samples
+    compute_centroids
+    determine_medoids
+    synthetic_obs_distribution
+    _destandardize
     get_freq_band
     texture_of_complex_phase
     grid_displacement_pc
@@ -55,6 +63,8 @@ Radar retrievals
     detect_ml
     melting_layer_giangrande
     melting_layer_hydroclass
+    melting_layer_mf
+    compute_apparent_profile
     _get_res_vol_sides
     velocity_azimuth_display
     quasi_vertical_profile
@@ -92,15 +102,19 @@ Radar retrievals
     compute_Doppler_width_iq
     compute_pol_variables_iq
     compute_spectra
+    gecsx
 
 """
 from .ml import detect_ml, melting_layer_giangrande, melting_layer_hydroclass
-from .ml import _get_res_vol_sides
+from .ml import _get_res_vol_sides, compute_apparent_profile, melting_layer_mf
+from .ml import get_ml_rng_limits, get_iso0_val
 from .kdp_proc import kdp_maesaka, kdp_schneebeli, kdp_vulpiani
 from .kdp_proc import kdp_leastsquare_single_window
 from .kdp_proc import kdp_leastsquare_double_window
 from .echo_class import steiner_conv_strat, hydroclass_semisupervised
-from .echo_class import get_freq_band
+from .echo_class import get_freq_band, data_for_centroids, compute_centroids
+from .echo_class import select_samples, determine_medoids, _destandardize
+from .echo_class import synthetic_obs_distribution
 from .gate_id import map_profile_to_gates, fetch_radar_time_profile
 from .simple_moment_calculations import calculate_snr_from_reflectivity
 from .simple_moment_calculations import calculate_velocity_texture
@@ -135,5 +149,6 @@ from .iq import compute_Doppler_velocity_iq, compute_Doppler_width_iq
 from .iq import compute_pol_variables_iq, compute_spectra
 from .iq import compute_mean_phase_iq, compute_st1_iq, compute_st2_iq
 from .iq import compute_wbn_iq
+from .gecsx import gecsx
 
 __all__ = [s for s in dir() if not s.startswith('_')]
